Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1489)

Unified Diff: tests/language/library1a_test.dart

Issue 10968010: Import scope rules updated. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/language/library1a_test.dart
diff --git a/tests/language/library6.dart b/tests/language/library1a_test.dart
similarity index 73%
copy from tests/language/library6.dart
copy to tests/language/library1a_test.dart
index 154c1e0d9ff2ac7cbf322dfa1b5d2f02c4516f6f..6110319def088edb36cf5b785336c0b14e021ddc 100644
--- a/tests/language/library6.dart
+++ b/tests/language/library1a_test.dart
@@ -7,11 +7,12 @@
// another function type alias with the same name.
// This name conflict is considered an error even if Fun is never referred to.
-#library("Library6NegativeTest.dart");
-#import("library5a.dart"); // Defines function type alias Fun
+#library("library1a_test.dart");
+#import("library1.dart"); // Defines top level variable 'foo'
-typedef int Fun(); // Does not conflict with definition of Fun from library5a
+var foo = 42; // Does not conflict with definition of foo from library1
main() {
+ print(foo);
}
« lib/compiler/implementation/resolver.dart ('K') | « lib/compiler/implementation/warnings.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698